==> GOstats_2.18.0.zip: GOstats/doc/GOstatsForUnsupportedOrganisms.R <==
###################################################
### chunk number 1: available Schemas
###################################################
#line 47 "GOstatsForUnsupportedOrganisms.Rnw"
library("AnnotationDbi")
available.dbschemas()


###################################################
### chunk number 2: Acquire annotation data
###################################################
#line 69 "GOstatsForUnsupportedOrganisms.Rnw"
library("org.Hs.eg.db")
frame = toTable(org.Hs.egGO)
goframeData = data.frame(frame$go_id, frame$Evidence, frame$gene_id)
head(goframeData)


###################################################
### chunk number 3: transformGOFrame
###################################################
#line 94 "GOstatsForUnsupportedOrganisms.Rnw"
goFrame=GOFrame(goframeData,organism="Homo sapiens")
goAllFrame=GOAllFrame(goFrame)


###################################################
### chunk number 4: Make GSC
###################################################
#line 105 "GOstatsForUnsupportedOrganisms.Rnw"
library("GSEABase")
gsc <- GeneSetCollection(goAllFrame, setType = GOCollection())


###################################################
### chunk number 5: <make parameter
###################################################
#line 121 "GOstatsForUnsupportedOrganisms.Rnw"
library("GOstats")
universe = Lkeys(org.Hs.egGO)
genes = universe[1:500]
params <- GSEAGOHyperGParams(name="My Custom GSEA based annot Params", 
                             geneSetCollection=gsc, 
                             geneIds = genes, 
                             universeGeneIds = universe, 
                             ontology = "MF", 
                             pvalueCutoff = 0.05, 
                             conditional = FALSE, 
                             testDirection = "over")


###################################################
### chunk number 6: call HyperGTest
###################################################
#line 138 "GOstatsForUnsupportedOrganisms.Rnw"
Over <- hyperGTest(params)
head(summary(Over))


###################################################
### chunk number 7: KEGGFrame object
###################################################
#line 154 "GOstatsForUnsupportedOrganisms.Rnw"
frame = toTable(org.Hs.egPATH)
keggframeData = data.frame(frame$path_id, frame$gene_id)
head(keggframeData)
keggFrame=KEGGFrame(keggframeData,organism="Homo sapiens")


###################################################
### chunk number 8: KEGG Parameters
###################################################
#line 163 "GOstatsForUnsupportedOrganisms.Rnw"
gsc <- GeneSetCollection(keggFrame, setType = KEGGCollection())
universe = Lkeys(org.Hs.egGO)
genes = universe[1:500]
kparams <- GSEAKEGGHyperGParams(name="My Custom GSEA based annot Params", 
                               geneSetCollection=gsc, 
                               geneIds = genes, 
                               universeGeneIds = universe,  
                               pvalueCutoff = 0.05, 
                               testDirection = "over")
kOver <- hyperGTest(params)
head(summary(kOver))


###################################################
### chunk number 9: info
###################################################
#line 178 "GOstatsForUnsupportedOrganisms.Rnw"
toLatex(sessionInfo())

==> GOstats_2.22.0.zip: GOstats/doc/GOstatsForUnsupportedOrganisms.R <==
### R code from vignette source 'GOstatsForUnsupportedOrganisms.Rnw'

###################################################
### code chunk number 1: available Schemas
###################################################
library("AnnotationDbi")
available.dbschemas()


###################################################
### code chunk number 2: Acquire annotation data
###################################################
library("org.Hs.eg.db")
frame = toTable(org.Hs.egGO)
goframeData = data.frame(frame$go_id, frame$Evidence, frame$gene_id)
head(goframeData)


###################################################
### code chunk number 3: transformGOFrame
###################################################
goFrame=GOFrame(goframeData,organism="Homo sapiens")
goAllFrame=GOAllFrame(goFrame)


###################################################
### code chunk number 4: Make GSC
###################################################
library("GSEABase")
gsc <- GeneSetCollection(goAllFrame, setType = GOCollection())


###################################################
### code chunk number 5: <make parameter
###################################################
library("GOstats")
universe = Lkeys(org.Hs.egGO)
genes = universe[1:500]
params <- GSEAGOHyperGParams(name="My Custom GSEA based annot Params", 
                             geneSetCollection=gsc, 
                             geneIds = genes, 
                             universeGeneIds = universe, 
                             ontology = "MF", 
                             pvalueCutoff = 0.05, 
                             conditional = FALSE, 
                             testDirection = "over")


###################################################
### code chunk number 6: call HyperGTest
###################################################
Over <- hyperGTest(params)
head(summary(Over))


###################################################
### code chunk number 7: KEGGFrame object
###################################################
frame = toTable(org.Hs.egPATH)
keggframeData = data.frame(frame$path_id, frame$gene_id)
head(keggframeData)
keggFrame=KEGGFrame(keggframeData,organism="Homo sapiens")


###################################################
### code chunk number 8: KEGG Parameters
###################################################
gsc <- GeneSetCollection(keggFrame, setType = KEGGCollection())
universe = Lkeys(org.Hs.egGO)
genes = universe[1:500]
kparams <- GSEAKEGGHyperGParams(name="My Custom GSEA based annot Params", 
                               geneSetCollection=gsc, 
                               geneIds = genes, 
                               universeGeneIds = universe,  
                               pvalueCutoff = 0.05, 
                               testDirection = "over")
kOver <- hyperGTest(params)
head(summary(kOver))


###################################################
### code chunk number 9: info
###################################################
toLatex(sessionInfo())
